--Globals
local pairs_ = pairs
local table_insert = table.insert
local table_sort = table.sort
local table_getn = table.getn
local date_ = date

--Local
local folder, core = ...
setfenv(1, core)

CoreOptionsTable = {
	name = titleFull,
	type = "group",
	childGroups = "tab",

	args = {
		core={
			name = L["Core"],
			type = "group",
			order = 1,
			args={}
		},
		PoI = {
			name = L["People of Interest"],
			type = "group",
			order = 2,
			args={}
		}
	},
}



CoreOptionsTable.args.core.args.enable = {
	type = "toggle",	order	= 1,
	name	= L["Enable"],
	desc	= L["Enables / Disables the addon"],
	set = function(info,val) 
		if val == true then
			core:Enable()
		else
			core:Disable()
		end
	end,
	get = function(info) return core:IsEnabled() end
}

CoreOptionsTable.args.core.args.showWindow = {
	type = "execute",	order	= 10,
	name	= L["Show Window"],
	desc	= L["Bring up the main window."],
	func = function(info) 
		ShowWindow()
	end
}

defaultSettings.profile.relativeWhen		= true
CoreOptionsTable.args.core.args.relativeWhen = {
	name = L["Relative Date"],
	desc = L["Show how long it's been since receiving the money."],
	type = "toggle",
	order	= 11,
	set = function(info,val) 
		P.relativeWhen = val
		ShowWindow()
	end,
	get = function(info) return P.relativeWhen end
}


defaultSettings.profile.guildColour		= {r=0.2, g=1.0, b=0.2, a=1.0}
CoreOptionsTable.args.core.args.guildColour = {
	name = L["Guild Buyer"],	order	= 12,
	desc = L["Buyer colour if they're in your guild."],
	type = "color",
	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.guildColour.r = r
		P.guildColour.g = g
		P.guildColour.b = b
		P.guildColour.a = a
	end,
	get = function(info) return P.guildColour.r, P.guildColour.g, P.guildColour.b, P.guildColour.a end
}


defaultSettings.profile.friendColour		= {r=0.2, g=0.4, b=1, a=1.0}
CoreOptionsTable.args.core.args.friendColour = {
	name = L["Friend Buyer"],	order	= 13,
	desc = L["Buyer name if they're in your guild."],
	type = "color",
	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.friendColour.r = r
		P.friendColour.g = g
		P.friendColour.b = b
		P.friendColour.a = a
	end,
	get = function(info) return P.friendColour.r, P.friendColour.g, P.friendColour.b, P.friendColour.a end
}

defaultSettings.profile.PoIColour		= {r=1.0, g=0, b=0, a=1.0}
CoreOptionsTable.args.core.args.PoIColour = {
	name = L["PoI Buyer"],	order	= 14,
	desc = L["Buyer name if on People of Interest list."],
	type = "color",
	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.PoIColour.r = r
		P.PoIColour.g = g
		P.PoIColour.b = b
		P.PoIColour.a = a
	end,
	get = function(info) return P.PoIColour.r, P.PoIColour.g, P.PoIColour.b, P.PoIColour.a end
}



--People of interest
CoreOptionsTable.args.PoI.args.whatThisDo = {
	type = "description",	order = 1,
	width = "full",
	name = L["Names on this list will be coloured."],
}

tmpNewName = ""
CoreOptionsTable.args.PoI.args.inputName = {
	type = "input",	order	= 2,
	name = L["Name"],
	desc = L["Input a name"],
	set = function(info,val) 
		tmpNewName = val
	end,
	get = function(info) return tmpNewName end
}

CoreOptionsTable.args.PoI.args.addName = {
	type = "execute",	order	= 3,
	name	= L["Add Name"],
	desc	= L["Add name to list"],
	func = function(info) 
		if tmpNewName ~= "" then
			Debug("addName", tmpNewName)
			AddPoIName(tmpNewName)
			tmpNewName = ""
		end
	end
}

CoreOptionsTable.args.PoI.args.nameList = {
	type = "group",	order	= 6,
	name	= L["Names"],
	args={}
}

function AddPoIName(name)
	if not fR.PoI[name] then
		fR.PoI[name] = {}
	end
	fR.PoI[name].when = date_("%c")
	
	BuildPoIList()
end

function BuildPoIList()
	CoreOptionsTable.args.PoI.args.nameList.args = {} --reset
	
	local list = {}
	for name, data in pairs_(fR.PoI) do 
		table_insert(list, name)
	end
	
	table_sort(list, function(a,b) 
		if(a and b) then 
			return a < b
		end 
	end)
	
	
	local playerName, data
	for i=1, table_getn(list) do 
		playerName = list[i]
		data = fR.PoI[playerName]
		
		CoreOptionsTable.args.PoI.args.nameList.args[playerName] = {
			type	= "group",
			name	= playerName,
--~ 			desc	= "someName",
			order = i,
			args={}
		}
		
		CoreOptionsTable.args.PoI.args.nameList.args[playerName].args.addedWhen = {
			type = "description",	order = 1,
			name = L["Added: "]..data.when,
		}
		
		
		CoreOptionsTable.args.PoI.args.nameList.args[playerName].args.removeName = {
			type = "execute",	order	= 10,
			name	= L["Remove Name"],
			desc	= L["Remove name from list"],
			func = function(info) 
				RemoveName(info[3])
			end
		}
		
	end
	
end

function RemoveName(name)
	fR.PoI[name] = nil
	BuildPoIList()
	echo(L["Removed |cffffff00%s|r from list."]:format(name))
end